FunctionSignatureParamFlags

Struct FunctionSignatureParamFlags 

pub struct FunctionSignatureParamFlags {
    pub dead: bool,
    pub owned_to_guaranteed: bool,
    pub exploded: bool,
    pub guaranteed_to_owned: bool,
    pub existential_to_generic: bool,
}
Option flags that can be combined with the base param kind.

Fields

dead: bool

Parameter was found dead (unused) and removed.

owned_to_guaranteed: bool

Owned parameter converted to guaranteed (borrowed).

exploded: bool

Exploded (SROA - Scalar Replacement of Aggregates) - struct/tuple split into fields.

guaranteed_to_owned: bool

Guaranteed parameter converted to owned.

existential_to_generic: bool

Existential parameter specialized to concrete type.

Implementations

Source

impl FunctionSignatureParamFlags

pub fn any(&self) -> bool

Returns true if any flag is set.

pub fn names(&self) -> Vec<&'static str>

Get a list of flag names that are set.