pub struct GenericSignature<'ctx> { /* private fields */ }Expand description
A generic signature describing generic parameters and their constraints.
Implementations
Sourceimpl<'ctx> GenericSignature<'ctx>
impl<'ctx> GenericSignature<'ctx>
Sourcepub fn new(raw: Node<'ctx>) -> Self
pub fn new(raw: Node<'ctx>) -> Self
Create a GenericSignature from a raw DependentGenericSignature node.
Sourcepub fn param_counts(&self) -> Vec<u64>
pub fn param_counts(&self) -> Vec<u64>
Get the number of generic parameters at each depth level.
Returns a vector where index 0 is depth 0 params, index 1 is depth 1 params, etc.
Sourcepub fn requirements(&self) -> Vec<GenericRequirement<'ctx>>
pub fn requirements(&self) -> Vec<GenericRequirement<'ctx>>
Get all generic requirements (constraints).