pub struct TypeRef<'ctx> { /* private fields */ }Expand description
A reference to a Swift type.
This wraps a raw node and provides methods to extract type information. The type information is parsed lazily when accessed.
Implementations
Sourceimpl<'ctx> TypeRef<'ctx>
impl<'ctx> TypeRef<'ctx>
Sourcepub fn generic_args(&self) -> Vec<TypeRef<'ctx>>
pub fn generic_args(&self) -> Vec<TypeRef<'ctx>>
Get generic arguments if this is a generic type.
Returns an empty vector if this is not a generic type.
Sourcepub fn is_generic(&self) -> bool
pub fn is_generic(&self) -> bool
Check if this is a generic type.