pub struct Function<'ctx> { /* private fields */ }Expand description
A Swift function symbol.
Implementations
Sourceimpl<'ctx> Function<'ctx>
impl<'ctx> Function<'ctx>
Sourcepub fn new_static(raw: Node<'ctx>) -> Self
pub fn new_static(raw: Node<'ctx>) -> Self
Create a Function from a raw node, marking it as static.
Sourcepub fn context(&self) -> SymbolContext<'ctx>
pub fn context(&self) -> SymbolContext<'ctx>
Get the context (location) where this function is defined.
Sourcepub fn labels(&self) -> Vec<Option<&'ctx str>>
pub fn labels(&self) -> Vec<Option<&'ctx str>>
Get the argument labels for this function.
Returns a vector where each element is Some(label) for labeled parameters
and None for unlabeled parameters (using _).
Sourcepub fn return_type(&self) -> Option<TypeRef<'ctx>>
pub fn return_type(&self) -> Option<TypeRef<'ctx>>
Get the return type of this function.
Sourcepub fn containing_type(&self) -> Option<&'ctx str>
pub fn containing_type(&self) -> Option<&'ctx str>
Get the containing type name if this is a method.
Sourcepub fn containing_type_is_class(&self) -> bool
pub fn containing_type_is_class(&self) -> bool
Check if the containing type is a class (reference type).
Sourcepub fn containing_type_is_protocol(&self) -> bool
pub fn containing_type_is_protocol(&self) -> bool
Check if the containing type is a protocol.